# Projecto pruebas en python
---
Paquete que instala la aplicacion saluda, solo para probar como empaquetar con python usando dependencias y descargando desde PyPi.

### Aspectos técnicos 


Luego es importante incluir en el archivo `setup.py`

`include_package_data=True,`



## Instalación 

### Dentro del direcotrio del proyecto pruebas ejecutar:
```cmd
## Uso


## Contribuciones
Son bienvenidos las peticiones de pull, vea primero la lista de asuntos en discución de que le gutaría modificar.

## Liciencia
[MIT](https://opensource.org/licenses/mit-license.php)
